@@ -14,8 +14,6 @@
 # pylint: disable=too-many-branches
 # pylint: disable=too-many-statements
 
-from __future__ import absolute_import, print_function
-
 import json
 import logging
 import os
@@ -314,6 +312,7 @@ def _evaluate_tags(pcluster_config, preferred_tags=None):
     tags = {}
 
     configured_tags = pcluster_config.get_section("cluster").get_param_value("tags")
+    _add_intel_tags(pcluster_config, tags)
     if configured_tags:
         tags.update(configured_tags)
 
@@ -328,6 +327,11 @@ def _evaluate_tags(pcluster_config, preferred_tags=None):
     return [{"Key": tag, "Value": tags[tag]} for tag in tags]
 
 
+def _add_intel_tags(pcluster_config, tags):
+    if pcluster_config.get_section("cluster").get_param_value("enable_intel_hpc_platform"):
+        tags.update({"aws-parallelcluster-intel-hpc": "enable_intel_hpc_platform=true"})
+
+
 def _print_compute_fleet_status(cluster_name, stack):
     outputs = stack.get("Outputs", [])
     if utils.get_stack_output_value(outputs, "IsHITCluster") == "true":
@@ -367,7 +371,7 @@ def _is_ganglia_enabled(parameters):
     try:
         cfn_extra_json = utils.get_cfn_param(parameters, "ExtraJson")
         is_ganglia_enabled = json.loads(cfn_extra_json).get("cfncluster").get("ganglia_enabled") == "yes"
-    except Exception:
+    except Exception:  # nosec
         pass
     return is_ganglia_enabled
 
@@ -519,7 +523,12 @@ def ssh(args, extra_args):  # noqa: C901 FIXME!!!
         log_message = "SSH command: {0}".format(cmd)
         if not args.dryrun:
             LOGGER.debug(log_message)
-            os.system(cmd)
+            # A nosec comment is appended to the following line in order to disable the B605 check.
+            # This check is disabled for the following reasons:
+            # - The args passed to the remote command are sanitized.
+            # - The default command to which these args is known.
+            # - Users have full control over any customization of the command to which args are passed.
+            os.system(cmd)  # nosec nosemgrep
         else:
             LOGGER.info(log_message)
     except KeyboardInterrupt:
